@@ -76,7 +76,7 @@ void TQTrayLabel::initialize(void)
   setAlignment(TQt::AlignCenter);
   setBackgroundMode(X11ParentRelative);
 
-  connect(&mRealityMonitor, SIGNAL(timeout()), this, SLOT(realityCheck()));
+  connect(&mRealityMonitor, TQ_SIGNAL(timeout()), this, TQ_SLOT(realityCheck()));
   setDockedWindow(mDockedWindow);
 
   sysTrayStatus(TQPaintDevice::x11AppDisplay(), &mSysTray);
@@ -198,7 +198,7 @@ void TQTrayLabel::realityCheck(void)
   if (!(attr.your_event_mask & SubstructureNotifyMask))
   {
     subscribe(display, None, SubstructureNotifyMask, true);
-    TRACE("%s rescanning clients since qt overrode mask", me());
+    TRACE("%s rescanning clients since tqt overrode mask", me());
     scanClients();
   }
 
@@ -254,7 +254,7 @@ void TQTrayLabel::dock(void)
   Window wid = winId();
 
   // 1. GNOME and NET WM Specification
-  long l[5] = { CurrentTime, SYSTEM_TRAY_REQUEST_DOCK, wid, 0, 0 };
+  unsigned long l[5] = { CurrentTime, SYSTEM_TRAY_REQUEST_DOCK, wid, 0, 0 };
   sendMessage(display, mSysTray, mSysTray, "_NET_SYSTEM_TRAY_OPCODE",
               32, 0L, l, sizeof(l));
 
@@ -288,7 +288,7 @@ void TQTrayLabel::dock(void)
    * working with with a delay of as little as 50ms. But since I
    * dont understand why this delay is required, I am justifiably paranoid
    */
-  TQTimer::singleShot(500, this, SLOT(show()));
+  TQTimer::singleShot(500, this, TQ_SLOT(show()));
 
   // let the world know
   emit docked(this);
@@ -330,7 +330,7 @@ void TQTrayLabel::map(void)
        * the WM 200ms to do that. We will override that value to -1 (all
        * desktops) on showOnAllDesktops().
        */
-       TQTimer::singleShot(200, this, SLOT(showOnAllDesktops()));
+       TQTimer::singleShot(200, this, TQ_SLOT(showOnAllDesktops()));
   }
 
   /*
@@ -355,13 +355,13 @@ void TQTrayLabel::map(void)
   sendMessage(display, tqt_xrootwin(), mDockedWindow, "_NET_ACTIVE_WINDOW", 32,
               SubstructureNotifyMask | SubstructureRedirectMask, l, sizeof(l));
   // skipTaskbar modifies _NET_WM_STATE. Make sure we dont override WMs value
-  TQTimer::singleShot(230, this, SLOT(skipTaskbar()));
+  TQTimer::singleShot(230, this, TQ_SLOT(skipTaskbar()));
   // disable "dock when minized" (if enable) for a short while since we went to Iconic state
   // (when the window is mapped, often an IconicState WM_STATE message is sent too
   // just before the NormalState)
   mSavedDWM = mDockWhenMinimized->isChecked(); // store for later use
   mDockWhenMinimized->setChecked(false);
-  TQTimer::singleShot(500, this, SLOT(toggleDockWhenMinimized()));
+  TQTimer::singleShot(500, this, TQ_SLOT(toggleDockWhenMinimized()));
 }
 
 void TQTrayLabel::withdraw(void)
@@ -574,7 +574,7 @@ void TQTrayLabel::setDockedWindow(Window w)
     if (mWithdrawn)
     {
       // show the window for sometime before docking
-      TQTimer::singleShot(500, this, SLOT(withdraw()));
+      TQTimer::singleShot(500, this, TQ_SLOT(withdraw()));
     }
     else map();
     dock();
@@ -622,7 +622,7 @@ void TQTrayLabel::balloonText()
 
   mBalloon->move(p);
   mBalloon->show();
-  TQTimer::singleShot(mBalloonTimeout, mBalloon, SLOT(hide()));
+  TQTimer::singleShot(mBalloonTimeout, mBalloon, TQ_SLOT(hide()));
 #endif
 }
 
@@ -840,7 +840,7 @@ void TQTrayLabel::mapEvent(void)
    * the window. So we disable it for sometime and reanable.
    */
     mDockWhenObscured->setChecked(false);
-    TQTimer::singleShot(800, mDockWhenObscured, SLOT(toggle()));
+    TQTimer::singleShot(800, mDockWhenObscured, TQ_SLOT(toggle()));
     TRACE("Turning off DWO for some time");
   }
 }
@@ -981,13 +981,13 @@ void TQTrayLabel::installMenu()
 
   mOptionsMenu = new TDEPopupMenu(this);
   mDockWhenRestored = new TDEToggleAction(i18n("Dock when session restored"), 0, this);
-  connect(mDockWhenRestored, SIGNAL(toggled(bool)), this, SLOT(setDockWhenRestored(bool)));
+  connect(mDockWhenRestored, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setDockWhenRestored(bool)));
   mDockWhenRestored->plug(mOptionsMenu);
 
-  mOptionsMenu->insertItem(i18n("Set Icon"), this, SLOT(setCustomIcon()));
+  mOptionsMenu->insertItem(i18n("Set Icon"), this, TQ_SLOT(setCustomIcon()));
 
   mBalloonTimeoutAction = new TDEAction(i18n("Set balloon timeout"), 0, this);
-  connect(mBalloonTimeoutAction, SIGNAL(activated()), this, SLOT(slotSetBalloonTimeout()));
+  connect(mBalloonTimeoutAction, TQ_SIGNAL(activated()), this, TQ_SLOT(slotSetBalloonTimeout()));
   mBalloonTimeoutAction->plug(mOptionsMenu);
 
   mDockWhenObscured = new TDEToggleAction(i18n("Dock when obscured"), 0, this);
@@ -1000,25 +1000,25 @@ void TQTrayLabel::installMenu()
   mDockWhenFocusLost->plug(mOptionsMenu);
 
   mSkipTaskbar = new TDEToggleAction(i18n("Skip taskbar"), 0, this);
-  connect(mSkipTaskbar, SIGNAL(toggled(bool)), this, SLOT(setSkipTaskbar(bool)));
+  connect(mSkipTaskbar, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(setSkipTaskbar(bool)));
   mSkipTaskbar->plug(mOptionsMenu);
 
   mMainMenu = new TDEPopupMenu(this);
   mMainMenu->insertItem(i18n("Options"), mOptionsMenu);
-  mMainMenu->insertItem(i18n("Dock Another"), tlMgr, SLOT(dockAnother()));
-  mMainMenu->insertItem(i18n("Undock All"), tlMgr, SLOT(undockAll()));
-  mMainMenu->insertItem(i18n("Quit All"), tlMgr, SLOT(quitAll()));
+  mMainMenu->insertItem(i18n("Dock Another"), tlMgr, TQ_SLOT(dockAnother()));
+  mMainMenu->insertItem(i18n("Undock All"), tlMgr, TQ_SLOT(undockAll()));
+  mMainMenu->insertItem(i18n("Quit All"), tlMgr, TQ_SLOT(quitAll()));
   mMainMenu->insertSeparator();
 
-  mShowId = mMainMenu->insertItem(TQString("Show/Hide [untitled]"), this, SLOT(toggleShow()));
-  mMainMenu->insertItem(TQString(i18n("Undock")), this, SLOT(undock()));
+  mShowId = mMainMenu->insertItem(TQString("Show/Hide [untitled]"), this, TQ_SLOT(toggleShow()));
+  mMainMenu->insertItem(TQString(i18n("Undock")), this, TQ_SLOT(undock()));
   mMainMenu->insertSeparator();
 
   mMainMenu->insertItem(SmallIcon("help"),KStdGuiItem::help().text(), (new KHelpMenu(this, TDEGlobal::instance()->aboutData()))->menu(), false);
-  TDEAction *quitAction = KStdAction::quit(this, SLOT(close()), NULL);
+  TDEAction *quitAction = KStdAction::quit(this, TQ_SLOT(close()), NULL);
   quitAction->plug(mMainMenu);
 
-  connect(mMainMenu, SIGNAL(aboutToShow()), this, SLOT(updateMenu()));
+  connect(mMainMenu, TQ_SIGNAL(aboutToShow()), this, TQ_SLOT(updateMenu()));
 
   // Apply defaults here
   mDockWhenObscured->setChecked(false);
